@@ -3,7 +3,7 @@ package Config::Properties;
 use strict;
 use warnings;
 
-our $VERSION = '0.47';
+our $VERSION = '0.49';
 
 use IO::Handle;
 # use Text::Wrap; loaded on demand
@@ -157,14 +157,17 @@ sub process_line {
     $line =~ /^\s*(\#|\!|$)/ and return 1;
 
     $self->{line_number}=$file->input_line_number;
-    chomp $line;
+    # chomp $line;
+    $line=~s/\x0D*\x0A$//;
 
     # handle continuation lines
     my @lines;
     while ($line =~ /(\\+)$/ and length($1) & 1) {
 	$line =~ s/\\$//;
 	push @lines, $line;
-	chomp($line = <$file>);
+	# chomp($line = <$file>);
+	$line = <$file>;
+	$line=~s/\x0D*\x0A$//;
 	$line =~ s/^\s+//;
     }
     $line=join('', @lines, $line) if @lines;
@@ -313,7 +316,7 @@ __END__
 
 =head1 NAME
 
-Config::Properties - read and write property files
+Config::Properties - Read and write property files
 
 =head1 SYNOPSIS
 
